#
# spec file for package python-pysol-cards
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pysol-cards
Version:        0.18.1
Release:        1.2
Summary:        Python module for pysol-cards
License:        Apache-2.0
URL:            https://pypi.org/project/pysol-cards/
Source:         https://files.pythonhosted.org/packages/source/p/pysol_cards/pysol_cards-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module random2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-random2
BuildArch:      noarch
%python_subpackages

%description
This module allows the python developer to generate the initial deals of some
PySol FC games. It also supports PySol legacy deals and Microsoft FreeCell /
Freecell Pro deals.

%prep
%autosetup -p1 -n pysol_cards-%{version}
find . -name "*.py" -exec sed -i '/\#\!\ \/usr\/bin\/env\ python/d' {} \;

%build
export LC_ALL=en_US.utf8
%pyproject_wheel

%install
export LC_ALL=en_US.utf8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/

%check
sed -i '/^addopts/d' setup.cfg
%pytest

%files %{python_files}
%doc AUTHORS CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/pysol_cards
%{python_sitelib}/pysol_cards-%{version}.dist-info

%changelog
* Tue Feb 25 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.18.1
  * Update build for/on fedora41
  * Remove entry point
- from version 0.18.0
  * Avoid "id" as a varname, because it clashes with a python built-in name
  * Remove remaining Python2 compat layer
  * Clean-up pydistman/cookiecutter fluff before PyPI
  * Clean-up pydistman/cookiecutter fluff before prepping a PyPI package
- Adjust sed statement to drop shebangs instead of modifying them
- Drop python-pysol-cards-no-six.patch, fixed upstream
- Remove pysol_cards binary from %%files section
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
* Thu Nov 28 2024 Dirk Müller <dmueller@suse.com>
- remove unneeded dependencies
* Mon Mar  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.16.0:
  * Add support for dealing "binary_star".
  * Add tests.
  * Try to fix getstate() / setstate() ; with tests
- Switch to pyproject and autosetup macros.
- No more greedy globs in %%files.
- Actually drop {Build,}Requires on six.
- Refresh python-pysol-cards-no-six.patch.
* Thu Dec  8 2022 pgajdos@suse.com
- version update to 0.14.2
  0.14.2
  * Avoid requiring optional deps - https://github.com/shlomif/pysol_cards/issues/4 .
  0.14.1
  * Avoid comments in requirements.txt - https://github.com/shlomif/pysol_cards/issues/4 .
  0.14.0
  * Convert from pbr to https://pypi.org/project/pydistman/ .
  0.12.0
  * bump ver
  * enhance the README
  * 'id' is a builtin
  * add a test using named arguments
  * optimize into a class var
  * optimize
  * add an integration test
- added patches
  fix https://github.com/shlomif/pysol_cards/issues/6
  + python-pysol-cards-no-six.patch
* Mon Jun  7 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Only build for python3- flavor, as -oslotest is only built for
  the main flavor too.
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.10.1
  * allow accepting "ms[0-9]+" game nums
  * add single\_deal\_args\_parse
  * better PySol compat: fix reset()
  * better PySol compat: str2int+int2str
* Sat Mar 14 2020 malcolmlewis@opensuse.org
- Initial build at version 0.8.8.
